@@ -6,9 +6,9 @@
 # @Email   :   bj.yan.pa@qq.com
 # @License :   Apache License 2.0
 
-from .opt import *
+from .cfg import *
 from .logger import *
 from .serial import *
 
 from .type import *
-from .dpm import *
\ No newline at end of file
+from .dpm import *
