@@ -19,8 +19,8 @@ def gaussian_noise(sensitivity, size, epsilon, **kwargs):
     :param kwargs: other parameters
     :return: the generated noise
     """
-    assert 'delta' in kwargs, 'delta is required'
-    delta = kwargs['delta']
+    assert "delta" in kwargs, "delta is required"
+    delta = kwargs["delta"]
     noise_scale = np.sqrt(2 * np.log(1.25 / delta)) * sensitivity / epsilon
     return np.random.normal(0, noise_scale, size)
 
@@ -33,4 +33,4 @@ def gaussian_clip(model: torch.nn.Module, clip: float):
     :return: None
     """
     for k, v in model.named_parameters():
-        v.grad /= max(1, v.grad.norm(2) / clip)
\ No newline at end of file
+        v.grad /= max(1, v.grad.norm(2) / clip)
