@@ -16,15 +16,21 @@ class Deserializer(object):
     """
 
     @staticmethod
-    def deserialize_model(model: torch.nn.Module, serialized_parameters: torch.Tensor, mode="copy"):
+    def deserialize_model(
+        model: torch.nn.Module, serialized_parameters: torch.Tensor, mode="copy"
+    ):
         cur_idx = 0
         for parameter in model.parameters():
             numel = parameter.data.numel()
             size = parameter.data.size()
             if mode == "copy":
-                parameter.data.copy_(serialized_parameters[cur_idx:cur_idx + numel].view(size))
+                parameter.data.copy_(
+                    serialized_parameters[cur_idx : cur_idx + numel].view(size)
+                )
             elif mode == "add":
-                parameter.data.add_(serialized_parameters[cur_idx:cur_idx + numel].view(size))
+                parameter.data.add_(
+                    serialized_parameters[cur_idx : cur_idx + numel].view(size)
+                )
             else:
                 raise ValueError("Unknown mode: {}".format(mode))
             cur_idx += numel
