@@ -14,11 +14,12 @@ from .base_aggregator import BaseAggregator
 
 
 class SyncAggregator(BaseAggregator):
-
     def __init__(self, args) -> None:
         super(SyncAggregator, self).__init__(args)
 
-        self.num_clients_per_round = int(args.num_clients * args.select_ratio)
+        self.num_clients_per_round = args.num_clients_per_round or int(
+            args.num_clients * args.select_ratio
+        )
         self._model_cached = []
         self._model_counter = 0
         self._model_weight = [
@@ -32,7 +33,7 @@ class SyncAggregator(BaseAggregator):
         if not self._check_agg():
             return
 
-        self.logger.info('Aggregate models')
+        self.logger.info("Aggregate models")
 
         new_param = torch.zeros_like(server_param)
         for i in range(self.num_clients_per_round):
@@ -45,13 +46,11 @@ class SyncAggregator(BaseAggregator):
         ]
 
         result = {
-            'param':
-                new_param,
-            'model_version':
-                kwargs["server_model_version"] +
-                1 if "server_model_version" in kwargs.keys() else 0,
-            'model_time':
-                time.time()
+            "param": new_param,
+            "model_version": kwargs["server_model_version"] + 1
+            if "server_model_version" in kwargs.keys()
+            else 0,
+            "model_time": time.time(),
         }
         return result
 
