@@ -6,7 +6,13 @@
 # @Email   :   bj.yan.pa@qq.com
 # @License :   Apache License 2.0
 
-__all__ = ["build_sampler", "RandomSampler", "NonIIDSampler", "sampler_factory", "BaseSampler"]
+__all__ = [
+    "build_sampler",
+    "RandomSampler",
+    "NonIIDSampler",
+    "sampler_factory",
+    "BaseSampler",
+]
 
 from .base_sampler import BaseSampler
 
@@ -14,14 +20,14 @@ from .random_sampler import RandomSampler
 from .noniid_sampler import NonIIDSampler
 
 sampler_factory = {
-    'random': RandomSampler,
-    'non-iid': NonIIDSampler,
+    "random": RandomSampler,
+    "non-iid": NonIIDSampler,
 }
 
 
 def build_sampler(sam_name: str):
     if sam_name not in sampler_factory.keys():
-        raise ValueError(f'Sampler {sam_name} not found.')
+        raise ValueError(f"Sampler {sam_name} not found.")
 
     sampler = sampler_factory[sam_name]
 
