@@ -13,7 +13,6 @@ from .base_sampler import BaseSampler
 
 
 class RandomSampler(BaseSampler):
-
     def __init__(self, args) -> None:
         super(RandomSampler, self).__init__(args)
 
@@ -21,7 +20,12 @@ class RandomSampler(BaseSampler):
         num_items = int(len(dataset) / self.args.num_clients)
         client_data_dict, all_idxs = {}, [i for i in range(len(dataset))]
         for i in range(self.args.num_clients):
-            client_data_dict[i] = list(np.random.choice(all_idxs, num_items, replace=False))
+            client_data_dict[i] = list(
+                np.random.choice(all_idxs, num_items, replace=False)
+            )
             all_idxs = list(set(all_idxs) - set(client_data_dict[i]))
 
-        return [ClientDataset(dataset, client_data_dict[i]) for i in range(self.args.num_clients)]
+        return [
+            ClientDataset(dataset, client_data_dict[i])
+            for i in range(self.args.num_clients)
+        ]
