@@ -6,20 +6,18 @@
 # @Email   :   bj.yan.pa@qq.com
 # @License :   Apache License 2.0
 
-__all__ = ["build_selector", "RandomFedAsyncSelector", "RandomSelector", "selector_factory"]
+__all__ = ["build_selector", "selector_factory", "RandomSelector"]
 
-from .random_fedasync_selector import RandomFedAsyncSelector
 from .random_selector import RandomSelector
 
 selector_factory = {
-    'random': RandomSelector,
-    'random_fedasync': RandomFedAsyncSelector,
+    "random": RandomSelector,
 }
 
 
 def build_selector(sele_name: str):
     if sele_name not in selector_factory.keys():
-        raise ValueError(f'{sele_name} is not a valid selector name')
+        raise ValueError(f"{sele_name} is not a valid selector name")
 
     selector = selector_factory[sele_name]
 
