@@ -6,20 +6,20 @@
 # @Email   :   bj.yan.pa@qq.com
 # @License :   Apache License 2.0
 
-__all__ = ["Trainer", "FedAsyncTrainer", "build_trainer", "trainer_factory", "BaseTrainer"]
+__all__ = ["build_trainer", "trainer_factory", "BaseTrainer", "DefaultTrainer"]
 
-from .trainer import Trainer
 from .base_trainer import BaseTrainer
-from .fedasync_trainer import FedAsyncTrainer
+from .default_trainer import DefaultTrainer
+
 
 trainer_factory = {
-    'trainer': Trainer,
-    'fedasync_trainer': FedAsyncTrainer,
+    "base_trainer": BaseTrainer,
+    "default_trainer": DefaultTrainer,
 }
 
 
 def build_trainer(trainer_type: str):
     if trainer_type not in trainer_factory.keys():
-        raise ValueError(f'{trainer_type} is not a valid trainer name')
+        raise ValueError(f"{trainer_type} is not a valid trainer name")
 
     return trainer_factory[trainer_type]
