@@ -13,7 +13,6 @@ from fedhf.model import build_criterion, build_optimizer, build_lr_scheduler
 
 
 class AbsTrainer(ABC):
-
     def __init__(self) -> None:
         super().__init__()
 
@@ -23,12 +22,14 @@ class AbsTrainer(ABC):
 
 
 class BaseTrainer(AbsTrainer):
-
     def __init__(self, args):
         self.args = args
         self.optim = build_optimizer(self.args.optim)
-        self.crit = build_criterion(self.args.train_loss)
-        self.lr_scheduler = build_lr_scheduler(self.args.lr_scheduler)
+        self.crit = build_criterion(self.args.loss)
+        if self.args.lr_scheduler:
+            self.lr_scheduler = build_lr_scheduler(self.args.lr_scheduler)
+        else:
+            self.lr_scheduler = None
         self.logger = Logger(self.args)
 
     def set_device(self, gpus, device):
