@@ -9,4 +9,4 @@
 from .server import *
 from .client import *
 from .coordinator import *
-from .injector import *
\ No newline at end of file
+from .registor import *
