@@ -10,11 +10,13 @@ __all__ = ["SimulatedClient", "build_client", "client_factory"]
 
 from .simulated_client import SimulatedClient
 
-client_factory = {'simulated': SimulatedClient}
+client_factory = {"simulated": SimulatedClient}
 
 
 def build_client(client_type):
     if client_type not in client_factory.keys():
-        raise ValueError('client_type {} not in {}'.format(client_type, client_factory.keys()))
+        raise ValueError(
+            "client_type {} not in {}".format(client_type, client_factory.keys())
+        )
     client = client_factory[client_type]
-    return client
\ No newline at end of file
+    return client
