@@ -12,9 +12,9 @@ from .random import RandomDataset
 from .client_datasest import ClientDataset
 
 dataset_factory = {
-    'mnist': MNISTDataset,
-    'cifar10': CIFAR10Dataset,
-    'random': RandomDataset,
+    "mnist": MNISTDataset,
+    "cifar10": CIFAR10Dataset,
+    "random": RandomDataset,
 }
 
 
@@ -28,6 +28,10 @@ def build_dataset(dataset_name: str):
 
 
 __all__ = [
-    'build_dataset', 'dataset_factory', 'MNISTDataset', 'CIFAR10Dataset', 'RandomDataset',
-    'ClientDataset'
+    "build_dataset",
+    "dataset_factory",
+    "MNISTDataset",
+    "CIFAR10Dataset",
+    "RandomDataset",
+    "ClientDataset",
 ]
