@@ -12,7 +12,6 @@ import torch
 
 
 class MNISTDataset(object):
-
     def __init__(self, args) -> None:
         super().__init__()
 
@@ -20,18 +19,18 @@ class MNISTDataset(object):
         self.num_classes = 10
 
         if args.resize:
-            self.transform = Compose([Resize([args.image_size, args.image_size]), ToTensor()])
+            self.transform = Compose(
+                [Resize([args.image_size, args.image_size]), ToTensor()]
+            )
         else:
             self.transform = Compose([ToTensor()])
 
-        self.trainset = MNIST(root=args.dataset_root,
-                              train=True,
-                              download=True,
-                              transform=self.transform)
-        self.testset = MNIST(root=args.dataset_root,
-                             train=False,
-                             download=True,
-                             transform=self.transform)
+        self.trainset = MNIST(
+            root=args.data_dir, train=True, download=True, transform=self.transform
+        )
+        self.testset = MNIST(
+            root=args.data_dir, train=False, download=True, transform=self.transform
+        )
 
         self.trainset.num_classes = self.num_classes
         self.testset.num_classes = self.num_classes
@@ -46,4 +45,4 @@ class MNISTDataset(object):
 
         mean = torch.mean(torch.tensor(means))
         std = torch.mean(torch.tensor(stds))
-        return {'mean': mean, 'std': std}
\ No newline at end of file
+        return {"mean": mean, "std": std}
