@@ -11,16 +11,16 @@ import torch.nn as nn
 import torch.optim as optim
 
 criterion_factory = {
-    'l1': nn.L1Loss,
-    'mse': nn.MSELoss,
-    'ce': nn.CrossEntropyLoss,
-    'bce': nn.BCELoss,
+    "l1": nn.L1Loss,
+    "mse": nn.MSELoss,
+    "ce": nn.CrossEntropyLoss,
+    "bce": nn.BCELoss,
 }
 
 
 def build_criterion(criter_name: str):
     if criter_name not in criterion_factory.keys():
-        raise ValueError(f'Unknown criterion name: {criter_name}')
+        raise ValueError(f"Unknown criterion name: {criter_name}")
 
     cirter = criterion_factory[criter_name]
     return cirter
