@@ -11,16 +11,16 @@ import torch.nn as nn
 import torch.optim as optim
 
 lr_schedule_factory = {
-    'step': optim.lr_scheduler.StepLR,
-    'multi_step': optim.lr_scheduler.MultiStepLR,
-    'exponential': optim.lr_scheduler.ExponentialLR,
-    'cosine': optim.lr_scheduler.CosineAnnealingLR,
+    "step": optim.lr_scheduler.StepLR,
+    "multi_step": optim.lr_scheduler.MultiStepLR,
+    "exponential": optim.lr_scheduler.ExponentialLR,
+    "cosine": optim.lr_scheduler.CosineAnnealingLR,
 }
 
 
 def build_lr_scheduler(lr_schedule_name: str):
     if lr_schedule_name not in lr_schedule_factory.keys():
-        raise ValueError(f'Unknown lr_schedule name: {lr_schedule_name}')
+        raise ValueError(f"Unknown lr_schedule name: {lr_schedule_name}")
 
     lr_scheduler = lr_schedule_factory[lr_schedule_name]
     return lr_scheduler
